@@ -1,13 +1,22 @@
 import os
 import subprocess
 
+try:
+    from staticfiles import finders
+except ImportError:
+    from django.contrib.staticfiles import finders # noqa
+
+from django.core.files.base import ContentFile
+from django.utils.encoding import smart_str
+
 from pipeline.conf import settings
-from pipeline.storage import storage
+from pipeline.storage import default_storage
 from pipeline.utils import to_class
 
 
 class Compiler(object):
-    def __init__(self, verbose=False):
+    def __init__(self, storage=default_storage, verbose=False):
+        self.storage = storage
         self.verbose = verbose
 
     def compilers(self):
@@ -22,10 +31,10 @@ class Compiler(object):
                     new_path = self.output_path(path, compiler.output_extension)
                     content = self.read_file(path)
                     try:
-                        compiled_content = compiler.compile_file(content, storage.path(path))
+                        compiled_content = compiler.compile_file(content, finders.find(path))
                         self.save_file(new_path, compiled_content)
                     except CompilerError:
-                        if not storage.exists(new_path) or not settings.PIPELINE:
+                        if not self.storage.exists(new_path) or not settings.PIPELINE:
                             raise
                     paths[index] = new_path
         return paths
@@ -35,15 +44,13 @@ class Compiler(object):
         return '.'.join((path[0], extension))
 
     def read_file(self, path):
-        file = storage.open(path, 'rb')
+        file = self.storage.open(path, 'rb')
         content = file.read()
         file.close()
         return content
 
     def save_file(self, path, content):
-        file = storage.open(path, 'wb')
-        file.write(content)
-        file.close()
+        return self.storage.save(path, ContentFile(smart_str(content)))
 
 
 class CompilerBase(object):
@@ -56,12 +63,6 @@ class CompilerBase(object):
     def compile_file(self, content, path):
         raise NotImplementedError
 
-    def save_file(self, path, content):
-        file = storage.open(path, 'wb')
-        file.write(content)
-        file.close()
-        return path
-
 
 class CompilerError(Exception):
     pass
