@@ -1,3 +1,4 @@
+import mimetypes
 import os
 import sys
 import urllib
@@ -5,6 +6,8 @@ import urllib
 from django.utils import importlib
 from django.utils.encoding import smart_str
 
+from pipeline.conf import settings
+
 
 def to_class(class_str):
     if not class_str:
@@ -22,6 +25,15 @@ def filepath_to_uri(path):
     return urllib.quote(smart_str(path).replace("\\", "/"), safe="/~!*()'#?")
 
 
+def guess_type(path, default=None):
+    for type, ext in settings.PIPELINE_MIMETYPES:
+        mimetypes.add_type(type, ext, strict=False)
+    mimetype, _ = mimetypes.guess_type(path, strict=False)
+    if not mimetype:
+        return default
+    return mimetype
+
+
 def _relpath_nt(path, start=os.path.curdir):
     """Return a relative version of a path"""
     if not path:
