@@ -1,26 +1,17 @@
 # -*- coding: utf-8 -*-
 import base64
-import sys
 
 from mock import patch
 
 from django.test import TestCase
-try:
-    from django.utils import unittest
-except ImportError:
-    import unittest2 as unittest
 
-from pipeline.conf import settings
-from pipeline.compressors import Compressor
+from pipeline.compressors import Compressor, TEMPLATE_FUNC
 from pipeline.compressors.yui import YUICompressor
 
 
 class CompressorTest(TestCase):
     def setUp(self):
         self.compressor = Compressor()
-        self.old_pipeline_url = settings.PIPELINE_URL
-        self.old_pipeline_root = settings.PIPELINE_ROOT
-        settings.PIPELINE_URL = 'http://localhost/static/'
 
     def test_js_compressor_class(self):
         self.assertEquals(self.compressor.js_compressor, YUICompressor)
@@ -32,15 +23,15 @@ class CompressorTest(TestCase):
         css = self.compressor.concatenate_and_rewrite([
             'css/first.css',
             'css/second.css'
-        ])
-        self.assertEquals(""".concat {\n  display: none;\n}\n.concatenate {\n  display: block;\n}""", css)
+        ], 'css/screen.css')
+        self.assertEquals(""".concat {\n  display: none;\n}\n\n.concatenate {\n  display: block;\n}\n""", css)
 
     def test_concatenate(self):
         js = self.compressor.concatenate([
             'js/first.js',
             'js/second.js'
         ])
-        self.assertEquals("""function concat() {\n  console.log(arguments);\n}\nfunction cat() {\n  console.log("hello world");\n}""", js)
+        self.assertEquals("""function concat() {\n  console.log(arguments);\n}\n\nfunction cat() {\n  console.log("hello world");\n}\n""", js)
 
     @patch.object(base64, 'b64encode')
     def test_encoded_content(self, mock):
@@ -51,9 +42,8 @@ class CompressorTest(TestCase):
         self.assertFalse(mock.called)
 
     def test_relative_path(self):
-        settings.PIPELINE_ROOT = '/var/www/static/'
-        relative_path = self.compressor.relative_path('/var/www/static/images/sprite.png')
-        self.assertEquals(relative_path, '/images/sprite.png')
+        relative_path = self.compressor.relative_path("images/sprite.png", 'css/screen.css')
+        self.assertEquals(relative_path, '../images/sprite.png')
 
     def test_base_path(self):
         base_path = self.compressor.base_path([
@@ -81,12 +71,12 @@ class CompressorTest(TestCase):
 
     def test_compile_templates(self):
         templates = self.compressor.compile_templates(['templates/photo/list.jst'])
-        self.assertEquals(templates, """window.JST = window.JST || {};\nwindow.JST['list'] = _.template('<div class="photo"> <img src="<%= src %>" /> <div class="caption">  <%= caption %> </div></div>');\n""")
+        self.assertEquals(templates, """window.JST = window.JST || {};\n%s\nwindow.JST['list'] = template('<div class="photo"> <img src="<%%= src %%>" /> <div class="caption">  <%%= caption %%> </div></div>');\n""" % TEMPLATE_FUNC)
         templates = self.compressor.compile_templates([
             'templates/video/detail.jst',
             'templates/photo/detail.jst'
         ])
-        self.assertEqual(templates, """window.JST = window.JST || {};\nwindow.JST['video_detail'] = _.template('<div class="video"> <video src="<%= src %>" /> <div class="caption">  <%= description %> </div></div>');\nwindow.JST[\'photo_detail\'] = _.template(\'<div class="photo"> <img src="<%= src %>" /> <div class="caption">  <%= caption %> by <%= author %> </div></div>\');\n""")
+        self.assertEqual(templates, """window.JST = window.JST || {};\n%s\nwindow.JST['video_detail'] = template('<div class="video"> <video src="<%%= src %%>" /> <div class="caption">  <%%= description %%> </div></div>');\nwindow.JST[\'photo_detail\'] = template(\'<div class="photo"> <img src="<%%= src %%>" /> <div class="caption">  <%%= caption %%> by <%%= author %%> </div></div>\');\n""" % TEMPLATE_FUNC)
 
     def test_embeddable(self):
         self.assertFalse(self.compressor.embeddable('images/sprite.png', None))
@@ -96,45 +86,29 @@ class CompressorTest(TestCase):
 
     def test_construct_asset_path(self):
         asset_path = self.compressor.construct_asset_path("../../images/sprite.png",
-            "css/plugins/gallery.css")
-        self.assertEquals(asset_path, "http://localhost/static/images/sprite.png")
+            "css/plugins/gallery.css", "css/gallery.css")
+        self.assertEquals(asset_path, "../images/sprite.png")
         asset_path = self.compressor.construct_asset_path("/images/sprite.png",
-            "css/plugins/gallery.css")
-        self.assertEquals(asset_path, "http://localhost/static/images/sprite.png")
-    
-    @unittest.skipUnless(sys.platform.startswith("win"), "requires Windows")
-    def test_construct_asset_path_windows(self):
-        asset_path = self.compressor.construct_asset_path("\image\sprite.png",
-            "css\plugins\gallery.css")
-        self.assertEquals(asset_path, "http://localhost/static/images/sprite.png")
-
-    def test_construct_asset_path_relative(self):
-        asset_path = self.compressor.construct_asset_path("../../images/sprite.png",
-            "css/plugins/gallery.css",
-            absolute_asset_paths=False)
-        self.assertEquals(asset_path, "../../images/sprite.png")
-        asset_path = self.compressor.construct_asset_path("/images/sprite.png",
-            "css/plugins/gallery.css",
-            absolute_asset_paths=False)
+            "css/plugins/gallery.css", "css/gallery.css")
         self.assertEquals(asset_path, "/images/sprite.png")
 
     def test_url_rewrite(self):
         output = self.compressor.concatenate_and_rewrite([
             'css/urls.css',
-        ])
+        ], 'css/screen.css')
         self.assertEquals("""@font-face {
   font-family: 'Pipeline';
-  src: url(http://localhost/static/fonts/pipeline.eot);
-  src: url(http://localhost/static/fonts/pipeline.eot?#iefix) format('embedded-opentype');
-  src: local('☺'), url(http://localhost/static/fonts/pipeline.woff) format('woff'), url(http://localhost/static/fonts/pipeline.ttf) format('truetype'), url(http://localhost/static/fonts/pipeline.svg#IyfZbseF) format('svg');
+  src: url(../fonts/pipeline.eot);
+  src: url(../fonts/pipeline.eot?#iefix) format('embedded-opentype');
+  src: local('☺'), url(../fonts/pipeline.woff) format('woff'), url(../fonts/pipeline.ttf) format('truetype'), url(../fonts/pipeline.svg#IyfZbseF) format('svg');
   font-weight: normal;
   font-style: normal;
 }
 .relative-url {
-  background-image: url(http://localhost/static/images/sprite-buttons.png);
+  background-image: url(../images/sprite-buttons.png);
 }
 .absolute-url {
-  background-image: url(http://localhost/static/images/sprite-buttons.png);
+  background-image: url(/images/sprite-buttons.png);
 }
 .absolute-full-url {
   background-image: url(http://localhost/images/sprite-buttons.png);
@@ -142,7 +116,3 @@ class CompressorTest(TestCase):
 .no-protocol-url {
   background-image: url(//images/sprite-buttons.png);
 }""", output)
-
-    def tearDown(self):
-        settings.PIPELINE_URL = self.old_pipeline_url
-        settings.PIPELINE_ROOT = self.old_pipeline_root
